-- plugin/gemini/api.lua

local M = {}

local api_key = vim.g.gemini_api_key -- Get API key from global variable

local function make_request(prompt)
	if not api_key then
		vim.notify(
			"Google AI API key not set.  Set g.gemini_api_key in your init.vim or init.lua.",
			vim.log.levels.ERROR
		)
		return nil
	end

	local model = "gemini-2.0-flash" -- SPECIFY Gemini 2.0 Flash MODEL
	-- Construct the JSON payload
	local payload = vim.json.encode({
		contents = {
			{
				parts = {
					{
						text = prompt,
					},
				},
			},
		},
	})

	local command = string.format(
		"curl -s -X POST "
			.. "'https://generative-ai.googleapis.com/v1beta/models/%s:generateContent?key=%s' "
			.. "-H 'Content-Type: application/json' "
			.. "-d '%s'",
		model,
		api_key,
		payload
	)

	local result = vim.fn.system(command)

	-- Check for errors during the curl execution
	if vim.v.shell_error ~= 0 then
		vim.notify("Error executing curl. Check your command and ensure curl is installed.", vim.log.levels.ERROR)
		return nil
	end

	local decoded_result = vim.json.decode(result)

	return decoded_result
end

function M.get_response(prompt)
	local result = make_request(prompt)

	if
		result
		and result.candidates
		and result.candidates[1]
		and result.candidates[1].content
		and result.candidates[1].content.parts
	then
		return result.candidates[1].content.parts[1].text
	else
		vim.notify("No response from Google AI API or malformed response.", vim.log.levels.ERROR)
		return nil
	end
end

return M
